package com.benyun.core.dao;

import com.benyun.core.entity.Category;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface CategoryMapper {
    List<Category> searchProvince();
    List<Category> searchCityByProvince(String province);
    List<Category> searchZoneByCity(String city);
    List<Category> searchBigCategory();
    List<Category> searchMidCategoryByBig(String bigCategory);
    List<Category> searchSubCategoryByMid(String midCategory);
    List<Category> searchWdType();
    List<Category> searchBigManage();
    List<Category> searchMidManageByBig(String bigCategory);
    List<Category> searchSubManageByMid(String midCategory);
}
